Constraint

Enum Constraint 

pub enum Constraint {
    Empty {
        bits: usize,
    },
    Unsigned {
        from: u64,
        to: u64,
        bits: usize,
    },
    Signed {
        from: i64,
        to: i64,
        bits: usize,
    },
    Full {
        bits: usize,
    },
}
A range of n-bit integers.

Variants



Empty

The empty range containing no values.

Fields

bits: usize

Bitsize of the integer this range constraints.



Unsigned

A range from-to, both inclusive.

Fields

from: u64

Lower bound (inclusive).

to: u64

Upper bound (inclusive).

bits: usize

Bitsize of the integer this range constraints.



Signed

A range from-to, both inclusive.

Fields

from: i64

Lower bound (inclusive).

to: i64

Upper bound (inclusive).

bits: usize

Bitsize of the integer this range constraints.



Full

A range containing all bits long integer.

Fields

bits: usize

Bitsize of the integer this range constraints.

Implementations

Source

impl Constraint

pub fn new(bits: usize) -> Result<Constraint>

Creates a new full ranges, bits large.

pub fn is_empty(&self) -> bool

Returns true if the range includes no values.

pub fn clamp_lower_bound_unsigned(&mut self, bound: u64)

Sets the lower bound to the unsigned value bound (inclusive).

pub fn clamp_lower_bound_signed(&mut self, bound: u64)

Sets the lower bound to the signed value bound (inclusive).

pub fn clamp_upper_bound_unsigned(&mut self, bound: u64)

Sets the upper bound to the unsigned value bound (inclusive).

pub fn clamp_upper_bound_signed(&mut self, bound: u64)

Sets the upper bound to the signed value bound (inclusive).

pub fn union_with(&mut self, other: Self)

Extends the range to include all values in other.

pub fn intersect_with(&mut self, other: Self)

Limits this range to the values in other.

pub fn include(&mut self, bound: u64)

Limits the range to bound.

pub fn exclude(&mut self, bound: u64)

Move the range to exclude bound.

pub fn bits(&self) -> usize

Size of the range bounds in bits.

pub fn limit(&self, v: Value) -> Value

Apply this range to v, returning either v itself of Undefined if it is outside.

pub fn signed(value: u64, bits: usize) -> i64

Helper to convert value to a bits large signed integer.

pub fn invert(&mut self)

Inverts the ranges to include all values it excluded before.

pub fn inverted(&self) -> Self

Returns the inverted range. See invert.